Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Agent ¶
type Agent struct {
Config *Config
Updates []*update.Update
// Ready indicates whether or not the Agent is ready to accept
// and process new commands. The Agent is only in a not-ready
// state when it is closing.
Ready bool
// Channels holds the state of all open channels. Closed channels
// are deleted. (Their history is still available in Updates.)
Channels map[string]*fsm.Channel
Messages map[string]*message.Message
EncryptedSeed []byte
NextKeypathIndex uint32
PrimaryAcct *fsm.AccountID
Wallet *fsm.WalletAcct
}
Agent is the db layout for a Starlight agent.
type Config ¶
type Config struct {
HorizonURL string
Username string
// PwType records which hashing function was used for PwHash.
// Currently, it's always "bcrypt".
PwType string
PwHash []byte
MaxRoundDurMins int64
FinalityDelayMins int64
ChannelFeerate int64
HostFeerate int64
KeepAlive bool
Public bool
}
Config is the db layout for Starlight agent-level configuration.
Click to show internal directories.
Click to hide internal directories.